@@ -2,6 +2,7 @@
 about
 """
 
+from dataclasses import dataclass
 from typing import List
 
 from sanic import Blueprint
@@ -11,16 +12,21 @@ from sanic_ext import openapi
 about_v1 = Blueprint("about_v1", url_prefix="/about")
 
 
+@dataclass
+class AboutGetV1Params:
+    """
+    AboutGetV1Params
+    """
+
+    mode: str
+    versions: List[str]
+
+
 @about_v1.get("/", version=1)
 @openapi.tag("General")
 @openapi.response(
     200,
-    {
-        "application/json": {
-            "mode": str,
-            "versions": List[str],
-        }
-    },
+    {"application/json": AboutGetV1Params},
     description="OK",
 )
 @openapi.description("Returns the supported API versions.")
